summaryrefslogtreecommitdiff
path: root/indra/newview
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview')
-rw-r--r--indra/newview/character/avatar_lad.xml20
-rw-r--r--indra/newview/lldynamictexture.cpp6
2 files changed, 13 insertions, 13 deletions
diff --git a/indra/newview/character/avatar_lad.xml b/indra/newview/character/avatar_lad.xml
index 90f06746c9..ee620b39b8 100644
--- a/indra/newview/character/avatar_lad.xml
+++ b/indra/newview/character/avatar_lad.xml
@@ -8923,8 +8923,8 @@
<!-- =========================================================== -->
<layer_set
body_region="hair"
- width="512"
- height="512"
+ width="1024"
+ height="1024"
clear_alpha="false">
<layer
name="base"
@@ -8953,8 +8953,8 @@
<layer_set
body_region="head"
- width="512"
- height="512">
+ width="1024"
+ height="1024">
<layer
name="head bump base"
fixed_color = "128,128,128,255"
@@ -10031,8 +10031,8 @@ render_pass="bump">
<!-- =========================================================== -->
<layer_set
body_region="upper_body"
- width="512"
- height="512">
+ width="1024"
+ height="1024">
<layer
name="base_upperbody bump"
render_pass="bump"
@@ -11282,8 +11282,8 @@ render_pass="bump">
<!-- =========================================================== -->
<layer_set
body_region="lower_body"
- width="512"
- height="512">
+ width="1024"
+ height="1024">
<layer
name="lower body bump base"
fixed_color = "128,128,128,255"
@@ -12241,8 +12241,8 @@ render_pass="bump">
<!-- =========================================================== -->
<layer_set
body_region="skirt"
- width="512"
- height="512"
+ width="1024"
+ height="1024"
clear_alpha="false">
<layer
name="skirt_fabric"
diff --git a/indra/newview/lldynamictexture.cpp b/indra/newview/lldynamictexture.cpp
index fa9a0712fa..87b56f33af 100644
--- a/indra/newview/lldynamictexture.cpp
+++ b/indra/newview/lldynamictexture.cpp
@@ -125,9 +125,9 @@ BOOL LLViewerDynamicTexture::render()
//-----------------------------------------------------------------------------
void LLViewerDynamicTexture::preRender(BOOL clear_depth)
{
- //only images up to 512x512 are supported
- llassert(mFullHeight <= 512);
- llassert(mFullWidth <= 512);
+ //only images up to 1024*1024 are supported
+ llassert(mFullHeight <= 1024);
+ llassert(mFullWidth <= 1024);
if (gGLManager.mHasFramebufferObject && gPipeline.mWaterDis.isComplete() && !gGLManager.mIsATI)
{ //using offscreen render target, just use the bottom left corner